%define _disable_ld_no_undefined 1

# We need to use C++17 to link against the system abseil-cpp, or we get linker
# errors.
%global cpp_std 17

%define major                   46
%define libaddress_sorting      %mklibname address_sorting %{major}
%define libgpr                  %mklibname gpr %{major}
%define libgrpc_unsecure        %mklibname grpc_unsecure %{major}
%define libgrpc                 %mklibname grpc %{major}
%define libupb_base_lib         %mklibname upb_base_lib %{major}
%define libupb_json_lib         %mklibname upb_json_lib %{major}
%define libupb_mem_lib          %mklibname upb_mem_lib %{major}
%define libupb_message_lib      %mklibname upb_message_lib %{major}
%define libupb_descriptor_lib   %mklibname upb_mini_descriptor_lib %{major}
%define libupb_textformat_lib   %mklibname upb_textformat_lib %{major}
%define libupb_wire_lib         %mklibname upb_wire_lib %{major}
%define libutf8_range_lib       %mklibname utf8_range_lib %{major}

%define majorpp                 1.71
%define libgrpcpp_alts          %mklibname grpc++_alts %{majorpp}
%define libgrpcpp_error_details %mklibname grpc++_error_details %{majorpp}
%define libgrpcpp_reflection    %mklibname grpc++_reflection %{majorpp}
%define libgrpcpp_test_config   %mklibname grpc++_test_config %{majorpp}
%define libgrpcpp_unsecure      %mklibname grpc++_unsecure %{majorpp}
%define libgrpcpp               %mklibname grpc++ %{majorpp}
%define libgrpcpp_channelz      %mklibname grpcpp_channelz %{majorpp}
%define libgrpc_autho_provider  %mklibname grpc_authorization_provider %{majorpp}
%define libgrpc_plugin_support  %mklibname grpc_plugin_support %{majorpp}

%define devname                 %mklibname %{name} -d

%bcond_without python

Name:           grpc
Version:        1.71.0
Release:        %mkrel 4
Summary:        Modern, open source, high-performance remote procedure call (RPC) framework
License:        ASL 2.0
Group:          System/Libraries
URL:            https://www.grpc.io
Source0:        https://github.com/grpc/grpc/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://storage.googleapis.com/grpc-bazel-mirror/github.com/census-instrumentation/opencensus-proto/archive/v0.3.0.tar.gz
Source2:        https://storage.googleapis.com/grpc-bazel-mirror/github.com/envoyproxy/data-plane-api/archive/4de3c74cf21a9958c1cf26d8993c55c6e0d28b49.tar.gz
Source3:        https://storage.googleapis.com/grpc-bazel-mirror/github.com/googleapis/googleapis/archive/fe8ba054ad4f7eca946c2d14a63c3f07c0b586a0.tar.gz
Source4:        https://storage.googleapis.com/grpc-bazel-mirror/github.com/bufbuild/protoc-gen-validate/archive/refs/tags/v1.2.1.zip
Source5:        https://storage.googleapis.com/grpc-bazel-mirror/github.com/cncf/xds/archive/3a472e524827f72d1ad621c4983dd5af54c46776.tar.gz
Source6:        https://github.com/google/googletest/archive/2dd1c131950043a8ad5ab0d2dda0e0970596586a.tar.gz
Patch10:        grpc-1.71.0-linking.patch
Patch11:        grpc-1.53.2-grpc_build-cli-always-and-install-cli.patch
Patch12:        grpc-no-opentelemetry_api.patch
Patch13:        no-sse2-on-arm.patch
BuildRequires:  cmake
BuildRequires:  cmake(absl)
BuildRequires:  gcc-c++
BuildRequires:  protobuf-compiler
BuildRequires:  gperftools-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig(benchmark)
BuildRequires:  pkgconfig(protobuf) >= 3.12.0
BuildRequires:  pkgconfig(openssl) > 1.1
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(gflags)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(re2)
BuildRequires:  pkgconfig(libxxhash)
BuildRequires:  pkgconfig(zlib)
%if %{with python}
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-cython
%endif

Requires:       %{libaddress_sorting} = %{version}-%{release}
Requires:       %{libgpr} = %{version}-%{release}
Requires:       %{libgrpc_unsecure} = %{version}-%{release}
Requires:       %{libgrpc} = %{version}-%{release}
Requires:       %{libgrpcpp_error_details} = %{version}-%{release}
Requires:       %{libgrpcpp_reflection} = %{version}-%{release}
Requires:       %{libgrpcpp_unsecure} = %{version}-%{release}
Requires:       %{libgrpcpp} = %{version}-%{release}
Requires:       %{libgrpcpp_channelz} = %{version}-%{release}
Requires:       %{libgrpc_autho_provider} = %{version}-%{release}
Requires:       %{libgrpc_plugin_support} = %{version}-%{release}

Provides:       bundled(opencensus-proto) = 0.3.0

%description
gRPC is a modern open source high performance RPC framework that can run in any
environment. It can efficiently connect services in and across data centers
with pluggable support for load balancing, tracing, health checking and
authentication. It is also applicable in last mile of distributed computing to
connect devices, mobile applications and browsers to backend services.

The main usage scenarios:

* Efficiently connecting polyglot services in microservices style architecture
* Connecting mobile devices, browser clients to backend services
* Generating efficient client libraries

Core Features that make it awesome:

* Idiomatic client libraries in 10 languages
* Highly efficient on wire and with a simple service definition framework
* Bi-directional streaming with http/2 based transport
* Pluggable auth, tracing, load balancing and health checking

#------------------------------------------------

%package        plugins
Summary:        gRPC protocol buffers compiler plugins
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       protobuf-compiler

%description    plugins
Plugins to the protocol buffers compiler to generate gRPC sources.

#------------------------------------------------

%package        cli
Summary:        gRPC protocol buffers cli
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}

%description    cli
Plugins to the protocol buffers compiler to generate gRPC sources.

#------------------------------------------------

%package -n     %{libaddress_sorting}
Summary:        Address Sorting library for gRPC
Group:          System/Libraries

%description -n %{libaddress_sorting}
Address Sorting library for gRPC.

#------------------------------------------------

%package -n     %{libgpr}
Summary:        Gpr library for gRPC
Group:          System/Libraries

%description -n %{libgpr}
Gpr library for gRPC.

#------------------------------------------------

%package -n     %{libgrpc_unsecure}
Summary:        gRPC Unsecure library
Group:          System/Libraries

%description -n %{libgrpc_unsecure}
gRPC Unsecure library.

#------------------------------------------------

%package -n     %{libgrpc}
Summary:        Main gRPC library
Group:          System/Libraries

%description -n %{libgrpc}
Main gRPC library.

#------------------------------------------------

%package -n     %{libupb_base_lib}
Summary:        gRPC Upb Base iblibrary
Group:          System/Libraries

%description -n %{libupb_base_lib}
gRPC Upb Base Lib library.

#------------------------------------------------

%package -n     %{libupb_json_lib}
Summary:        gRPC Upb Json Lib library
Group:          System/Libraries

%description -n %{libupb_json_lib}
gRPC Upb Json Lib library.

#------------------------------------------------

%package -n     %{libupb_mem_lib}
Summary:        gRPC Upb Mem Lib library
Group:          System/Libraries

%description -n %{libupb_mem_lib}
gRPC Upb Mem Lib library.

#------------------------------------------------

%package -n     %{libupb_message_lib}
Summary:        gRPC Upb Message Lib library
Group:          System/Libraries

%description -n %{libupb_message_lib}
gRPC Upb Message Lib library.

#------------------------------------------------

%package -n     %{libupb_descriptor_lib}
Summary:        gRPC Upb Mini Descriptor Lib library
Group:          System/Libraries

%description -n %{libupb_descriptor_lib}
gRPC Upb Mini Descriptor Lib library.

#------------------------------------------------

%package -n     %{libupb_textformat_lib}
Summary:        gRPC Upb Textformat Lib library
Group:          System/Libraries

%description -n %{libupb_textformat_lib}
gRPC Upb Textformat Lib library.

#------------------------------------------------

%package -n     %{libupb_wire_lib}
Summary:        gRPC Upb Wire Lib library
Group:          System/Libraries

%description -n %{libupb_wire_lib}
gRPC Upb Wire Lib library.

#------------------------------------------------

%package -n     %{libutf8_range_lib}
Summary:        gRPC Utf8 Range Lib library
Group:          System/Libraries

%description -n %{libutf8_range_lib}
gRPC Utf8 Range Lib library.

#------------------------------------------------

%package -n     %{libgrpcpp_alts}
Summary:        gRPC++ ALTS library
Group:          System/Libraries

%description -n %{libgrpcpp_alts}
gRPC++ ALTS library.

#------------------------------------------------

%package -n     %{libgrpcpp_error_details}
Summary:        gRPC++ Error Details library
Group:          System/Libraries

%description -n %{libgrpcpp_error_details}
gRPC++ Error Details library.

#------------------------------------------------

%package -n     %{libgrpcpp_reflection}
Summary:        gRPC++ Reflection library
Group:          System/Libraries

%description -n %{libgrpcpp_reflection}
gRPC++ Reflection library.

#------------------------------------------------

%package -n     %{libgrpcpp_test_config}
Summary:        gRPC++ Test config library
Group:          System/Libraries

%description -n %{libgrpcpp_test_config}
gRPC++ Test config library.

#------------------------------------------------

%package -n     %{libgrpcpp_unsecure}
Summary:        gRPC++ Unsecure library
Group:          System/Libraries

%description -n %{libgrpcpp_unsecure}
gRPC++ Unsecure library.

#------------------------------------------------

%package -n     %{libgrpcpp}
Summary:        Main gRPC++ library
Group:          System/Libraries

%description -n %{libgrpcpp}
Main gRPC++ library.

#------------------------------------------------

%package -n     %{libgrpcpp_channelz}
Summary:        gRPC++ Channelz library
Group:          System/Libraries

%description -n %{libgrpcpp_channelz}
gRPC++ Channelz library.

#------------------------------------------------

%package -n     %{libgrpc_autho_provider}
Summary:        gRPC Authorization Provider library
Group:          System/Libraries

%description -n %{libgrpc_autho_provider}
gRPC Authorization Provider library.

#------------------------------------------------

%package -n     %{libgrpc_plugin_support}
Summary:        gRPC Plugin support library
Group:          System/Libraries

%description -n %{libgrpc_plugin_support}
gRPC Plugin support library.

#------------------------------------------------

%package -n     %{devname}
Summary:        gRPC library development files
Group:          Development/C++
Requires:       %{name}-cli = %{version}-%{release}
Requires:       %{name}-plugins = %{version}-%{release}
Requires:       %{libaddress_sorting} = %{version}-%{release}
Requires:       %{libgpr} = %{version}-%{release}
Requires:       %{libgrpc_unsecure} = %{version}-%{release}
Requires:       %{libgrpc} = %{version}-%{release}
Requires:       %{libupb_base_lib} = %{version}-%{release}
Requires:       %{libupb_json_lib} = %{version}-%{release}
Requires:       %{libupb_mem_lib} = %{version}-%{release}
Requires:       %{libupb_message_lib} = %{version}-%{release}
Requires:       %{libupb_descriptor_lib} = %{version}-%{release}
Requires:       %{libupb_textformat_lib} = %{version}-%{release}
Requires:       %{libupb_wire_lib} = %{version}-%{release}
Requires:       %{libutf8_range_lib} = %{version}-%{release}
Requires:       %{libgrpcpp_error_details} = %{version}-%{release}
Requires:       %{libgrpcpp_reflection} = %{version}-%{release}
Requires:       %{libgrpcpp_test_config} = %{version}-%{release}
Requires:       %{libgrpcpp_unsecure} = %{version}-%{release}
Requires:       %{libgrpcpp} = %{version}-%{release}
Requires:       %{libgrpcpp_channelz} = %{version}-%{release}
Requires:       %{libgrpc_autho_provider} = %{version}-%{release}
Requires:       %{libgrpc_plugin_support} = %{version}-%{release}
Requires:       %{libgrpcpp_alts} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development headers and files for gRPC libraries.

#------------------------------------------------

%if %{with python}
%package -n     python3-grpcio
Summary:        Python3 language bindings for grpc, remote procedure call (RPC) framework
Group:          Development/Python
Requires:       %{name} = %{version}-%{release}
%{?python_provide:%python_provide python3-grpcio}

%description -n python3-grpcio
Python3 bindings for gRPC library.
%endif

#------------------------------------------------

%prep
%setup -q -a1 -a2 -a3 -a4 -a5 -a6
%autopatch -p1

# Do not DL third_party build dependencies
ln -s $(pwd)/opencensus-proto-*/src third_party/opencensus-proto/src
ln -s $(pwd)/data-plane-api-*/* third_party/envoy-api
ln -s $(pwd)/googleapis-*/* third_party/googleapis
ln -s $(pwd)/protoc-gen-validate-*/* third_party/protoc-gen-validate
ln -s $(pwd)/xds-*/* third_party/xds
ln -s $(pwd)/googletest-*/* third_party/googletest

# Remove bundled xxhash
rm -rvf third_party/xxhash
sed -i -e 's/\(_gRPC_XXHASH_INCLUDE_DIR\s\+\)\".*\"/\1"${CMAKE_INSTALL_INCLUDEDIR}"/' cmake/xxhash.cmake

# Remove Android sources and examples
rm -rvf examples/android src/android

# Drop the NodeJS example’s package-lock.json file, which will hopefully keep
# us from having bugs filed due to CVE’s in its (unpackaged) recursive
# dependencies.
rm -rvf examples/node/package-lock.json

# Remove unwanted .gitignore files, generally in examples. One could argue that
# a sample .gitignore file is part of the example, but, well, we’re not going
# to do that.
find . -type f -name .gitignore -print -delete

# We need to adjust the C++ standard to avoid abseil-related linker errors. For
# the main C++ build, we can use CMAKE_CXX_STANDARD. For extensions, examples,
# etc., we must patch.
sed -r -i 's/(std=c\+\+)1[1,4]/\1%{cpp_std}/g' \
    setup.py Rakefile \
    examples/cpp/*/Makefile \
    examples/cpp/*/CMakeLists.txt \
    tools/run_tests/artifacts/artifact_targets.py \
    tools/distrib/python/grpcio_tools/setup.py

%build
export CXXFLAGS="%{build_cxxflags} -Wno-attributes -Wno-deprecated-declarations"
%cmake -GNinja                            \
       -DCMAKE_CXX_STANDARD=%{cpp_std}    \
       -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
       -DgRPC_INSTALL=ON                  \
       -DgRPC_INSTALL_LIBDIR:PATH="%{_lib}" \
       -DgRPC_INSTALL_CMAKEDIR:PATH="%{_libdir}/cmake/grpc" \
       -DgRPC_BUILD_TESTS:BOOL=OFF        \
       -DgRPC_ABSL_PROVIDER=package       \
       -DgRPC_BENCHMARK_PROVIDER=package  \
       -DgRPC_CARES_PROVIDER=package      \
       -DgRPC_PROTOBUF_PROVIDER=package   \
       -DgRPC_RE2_PROVIDER=package        \
       -DgRPC_SSL_PROVIDER=package        \
       -DgRPC_ZLIB_PROVIDER=package       \
       -DgRPC_USE_SYSTEMD:BOOL=ON         \
       -DZLIB_LIBRARY=%{_libdir}/libz.so
%cmake_build

%if %{with python}
# build python module
export GRPC_PYTHON_BUILD_WITH_CYTHON=True
export GRPC_PYTHON_BUILD_SYSTEM_OPENSSL=True
export GRPC_PYTHON_BUILD_SYSTEM_ZLIB=True
export GRPC_PYTHON_BUILD_SYSTEM_CARES=True
export GRPC_PYTHON_BUILD_SYSTEM_RE2=True
export GRPC_PYTHON_BUILD_SYSTEM_ABSL=True
export GRPC_PYTHON_BUILD_WITH_SYSTEMD=True
export GRPC_BUILD_WITH_BORING_SSL_ASM=False
%pyproject_wheel
%endif

%install
%cmake_install

%if %{with python}
%pyproject_install
%endif

%files
%doc README.md
%license LICENSE
%{_datadir}/grpc/

%files cli
%doc README.md
%license LICENSE
%{_bindir}/grpc_cli

%files plugins
%doc README.md
%license LICENSE
%{_bindir}/grpc_*_plugin

%files -n %{libaddress_sorting}
%{_libdir}/libaddress_sorting.so.%{major}{,.*}

%files -n %{libgpr}
%{_libdir}/libgpr.so.%{major}{,.*}

%files -n %{libgrpc_unsecure}
%{_libdir}/libgrpc_unsecure.so.%{major}{,.*}

%files -n %{libgrpc}
%{_libdir}/libgrpc.so.%{major}{,.*}

%files -n %{libupb_base_lib}
%{_libdir}/libupb_base_lib.so.%{major}{,.*}

%files -n %{libupb_json_lib}
%{_libdir}/libupb_json_lib.so.%{major}{,.*}

%files -n %{libupb_mem_lib}
%{_libdir}/libupb_mem_lib.so.%{major}{,.*}

%files -n %{libupb_message_lib}
%{_libdir}/libupb_message_lib.so.%{major}{,.*}

%files -n %{libupb_descriptor_lib}
%{_libdir}/libupb_mini_descriptor_lib.so.%{major}{,.*}

%files -n %{libupb_textformat_lib}
%{_libdir}/libupb_textformat_lib.so.%{major}{,.*}

%files -n %{libupb_wire_lib}
%{_libdir}/libupb_wire_lib.so.%{major}{,.*}

%files -n %{libutf8_range_lib}
%{_libdir}/libutf8_range_lib.so.%{major}{,.*}

%files -n %{libgrpcpp_alts}
%{_libdir}/libgrpc++_alts.so.%{majorpp}{,.*}

%files -n %{libgrpcpp_error_details}
%{_libdir}/libgrpc++_error_details.so.%{majorpp}{,.*}

%files -n %{libgrpcpp_reflection}
%{_libdir}/libgrpc++_reflection.so.%{majorpp}{,.*}

%files -n %{libgrpcpp_test_config}
%{_libdir}/libgrpc++_test_config.so.%{majorpp}{,.*}

%files -n %{libgrpcpp_unsecure}
%{_libdir}/libgrpc++_unsecure.so.%{majorpp}{,.*}

%files -n %{libgrpcpp}
%{_libdir}/libgrpc++.so.%{majorpp}{,.*}

%files -n %{libgrpcpp_channelz}
%{_libdir}/libgrpcpp_channelz.so.%{majorpp}{,.*}

%files -n %{libgrpc_autho_provider}
%{_libdir}/libgrpc_authorization_provider.so.%{majorpp}{,.*}

%files -n %{libgrpc_plugin_support}
%{_libdir}/libgrpc_plugin_support.so.%{majorpp}{,.*}

%files -n %{devname}
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_libdir}/cmake/grpc/
%{_includedir}/grpc/
%{_includedir}/grpc++/
%{_includedir}/grpcpp/

%if %{with python}
%files -n python3-grpcio
%license LICENSE
%{python3_sitearch}/grpc/
%{python3_sitearch}/grpcio-%{version}.dist-info
%endif


%changelog
* Wed Mar 12 2025 pterjan <pterjan> 1.71.0-4.mga10
+ Revision: 2163018
- Try again to fix build on armv7hl
- Try to fix build on armv7hl

* Wed Mar 12 2025 daviddavid <daviddavid> 1.71.0-2.mga10
+ Revision: 2162947
- grpc is using a bundled copy of otel (opentelemetry_api), so there is
  no .pc file to depend on

* Tue Mar 11 2025 daviddavid <daviddavid> 1.71.0-1.mga10
+ Revision: 2162852
- new version: 1.71.0
- now libmajor is 46
- now libmajor++ is 1.71
- add some new libs
- disable tests build for now
- rebuild for new protobuf 30.0

* Sun Mar 09 2025 wally <wally> 1.53.2-5.mga10
+ Revision: 2162129
- rebuild for abseil-cpp 20250127.0

* Tue Mar 04 2025 wally <wally> 1.53.2-4.mga10
+ Revision: 2160371
- rebuild for python3.13

* Sun May 26 2024 cjw <cjw> 1.53.2-3.mga10
+ Revision: 2067769
- rebuild for abseil-cpp update

* Wed Dec 20 2023 daviddavid <daviddavid> 1.53.2-2.mga10
+ Revision: 2019985
- rebuild for py3.12

* Fri Sep 29 2023 daviddavid <daviddavid> 1.53.2-1.mga10
+ Revision: 1992190
- new version: 1.53.2
- switch to pyproject

* Mon Sep 25 2023 wally <wally> 1.48.1-6.mga10
+ Revision: 1990854
- build with cython 3.x

* Sun Sep 24 2023 daviddavid <daviddavid> 1.48.1-5.mga10
+ Revision: 1990396
- use the Cython compat package for now
- re-enable python-binding and add opensuse patch to fix noexcept
  errors upon compiling with cython 3

* Sat Sep 23 2023 daviddavid <daviddavid> 1.48.1-4.mga10
+ Revision: 1989505
- disable python binding for now as it is not yet compatible with cython 3
  https://github.com/cython/cython/issues/5305
- rebuild for new abseil-cpp 20230802.0

* Thu Sep 07 2023 daviddavid <daviddavid> 1.48.1-3.mga10
+ Revision: 1984955
- rebuild for new re2 20230901

* Thu Dec 22 2022 wally <wally> 1.48.1-2.mga9
+ Revision: 1925782
- rebuild for protobuf 21.12

* Sun Sep 11 2022 neoclust <neoclust> 1.48.1-1.mga9
+ Revision: 1886954
- New version  1.48.1

* Sun Sep 04 2022 papoteur <papoteur> 1.48.0-3.mga9
+ Revision: 1883737
- add missing requires of libgrpc_alts for devel package

* Mon Aug 08 2022 wally <wally> 1.48.0-2.mga9
+ Revision: 1876261
- rebuild for abseil-cpp 20220623.0

* Mon Aug 08 2022 wally <wally> 1.48.0-1.mga9
+ Revision: 1876216
- new version 1.48.0
- new lib major 26
- new c++ lib major 1.48
- build with bundled opencensus-proto 0.3.0
- build with system xxhash
- add chunks from Fedora .spec to %%prep

* Wed Mar 30 2022 umeabot <umeabot> 1.43.0-3.mga9
+ Revision: 1833795
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tv <tv> 1.43.0-2.mga9
+ Revision: 1778421
- Rebuild for python-3.10

* Wed Dec 29 2021 wally <wally> 1.43.0-1.mga9
+ Revision: 1765192
- new version 1.43.0
- new lib major 21
- new c++ lib major 1.43
- rebuild for protobuf 3.19.1
- rebuild for openssl 3.0.0

* Tue Mar 30 2021 daviddavid <daviddavid> 1.36.4-2.mga9
+ Revision: 1711937
- install missing gRPC++ Test config library
- conditional the cli support

* Tue Mar 30 2021 daviddavid <daviddavid> 1.36.4-1.mga9
+ Revision: 1711895
- new version: 1.36.4
- now libmajor is 15
- switch to cmake build system
- use system absl
- new gRPC Plugin support library
- drop removed upstream gRPC Csharp ext library

* Sat Mar 20 2021 daviddavid <daviddavid> 1.30.2-4.mga9
+ Revision: 1705278
- rebuild for python 3.9

* Fri Dec 18 2020 luigiwalser <luigiwalser> 1.30.2-3.mga8
+ Revision: 1660983
- rebuild for protobuf

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1.30.2-2.mga8
+ Revision: 1650738
- rebuild for protobuf

* Mon Jul 27 2020 daviddavid <daviddavid> 1.30.2-1.mga8
+ Revision: 1609252
- new version: 1.30.2

* Thu Jul 09 2020 daviddavid <daviddavid> 1.30.1-1.mga8
+ Revision: 1603755
- new version: 1.30.1

* Tue Jun 30 2020 daviddavid <daviddavid> 1.30.0-1.mga8
+ Revision: 1600749
- new version: 1.30.0
- now main libmajor is 10

* Tue Apr 21 2020 daviddavid <daviddavid> 1.28.1-1.mga8
+ Revision: 1570281
- new version: 1.28.1

* Tue Feb 18 2020 daviddavid <daviddavid> 1.27.2-2.mga8
+ Revision: 1541144
- new version: 1.27.2
- new version: 1.27.1
- new version: 1.27.0
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Thu Dec 19 2019 daviddavid <daviddavid> 1.26.0-1.mga8
+ Revision: 1468992
- new version: 1.26.0
- now libmajor is 9
- new version: 1.22.0
+ tv <tv>
- new release: 1.24.2
- rebuild with python 3.8
+ wally <wally>
- add upstream patches to fix build with glibc 2.30 and gcc9

* Sun Jun 30 2019 daviddavid <daviddavid> 1.20.1-1.mga8
+ Revision: 1416257
- new version: 1.20.1

* Wed Apr 17 2019 daviddavid <daviddavid> 1.20.0-1.mga7
+ Revision: 1391867
- new version: 1.20.0

* Mon Apr 01 2019 daviddavid <daviddavid> 1.19.0-1.mga7
+ Revision: 1384665
- new version: 1.19.0

* Mon Apr 01 2019 daviddavid <daviddavid> 1.18.0-1.mga7
+ Revision: 1384346
- initial package grpc

